##  Insights from Organization Fact Sheet
You can leverage [Matrix Report](https://help.sap.com/docs/leanix/ea/matrix-report?locale=en-US&state=PRODUCTION&version=CLOUD) to see how the organization structure you modeled utilized your applications. This can be useful to identify application redundancy in different locations of your organization. This will be beneficial for your [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.") initiatives.
